.. _WdTabAlignment:

``WD_TAB_ALIGNMENT``
====================

Specifies the tab stop alignment to apply.

----

LEFT
    Left-aligned.

CENTER
    Center-aligned.

RIGHT
    Right-aligned.

DECIMAL
    Decimal-aligned.

BAR
    Bar-aligned.

LIST
    List-aligned. (deprecated)

CLEAR
    Clear an inherited tab stop.

END
    Right-aligned.  (deprecated)

NUM
    Left-aligned.  (deprecated)

START
    Left-aligned.  (deprecated)
